@@ -2,6 +2,10 @@
 # Copyright (c) 2011-2013 Raphaël Barrois
 # This code is distributed under the two-clause BSD license.
 
+from __future__ import unicode_literals
+
+import sys
+
 from django import VERSION as django_version
 from django.core import exceptions
 from django.core import serializers
@@ -18,11 +22,19 @@ from django_xworkflows.xworkflow_log import models as xwlog_models
 
 try:
     import south
+    import south.orm
     import south.creator.freezer
     import south.modelsinspector
 except ImportError:
     south = None
 
+if sys.version_info[0] <= 2:
+    def text_type(text):
+        return unicode(text)
+else:
+    def text_type(text):
+        return str(text)
+
 from . import models
 
 
@@ -93,8 +105,8 @@ class ModelTestCase(test.TestCase):
 
     def test_display(self):
         o = models.MyWorkflowEnabled(other='aaa')
-        self.assertEqual(u"Foo", o.get_state_display())
-        self.assertEqual(u"AAA", o.get_other_display())
+        self.assertEqual("Foo", o.get_state_display())
+        self.assertEqual("AAA", o.get_other_display())
 
     def test_queries(self):
         models.MyWorkflowEnabled.objects.all().delete()
@@ -212,7 +224,7 @@ class TransitionTestCase(test.TransactionTestCase):
         self.assertEqual('foo', trlog.from_state)
         self.assertEqual('bar', trlog.to_state)
 
-        self.assertIn('foo -> bar', unicode(trlog))
+        self.assertIn('foo -> bar', text_type(trlog))
 
     def test_no_logging(self):
         """Tests disabled transition logs."""
@@ -323,8 +335,8 @@ class SouthTestCase(test.TestCase):
 
     frozen_workflow = (
         "__import__('xworkflows', globals(), locals()).base.WorkflowMeta("
-        "'MyWorkflow', (), {'states': (('foo', u'Foo'), ('bar', u'Bar'), "
-        "('baz', u'Baz')), 'initial_state': 'foo'})")
+        "'MyWorkflow', (), {'states': (('foo', 'foo'), ('bar', 'bar'), "
+        "('baz', 'baz')), 'initial_state': 'foo'})")
 
     def test_south_triple(self):
         field = models.MyWorkflowEnabled._meta.get_field_by_name('state')[0]
@@ -335,7 +347,7 @@ class SouthTestCase(test.TestCase):
                 'django_xworkflows.models.StateField',  # Class
                 [],  # *args
                 {
-                    'default': "'foo'",
+                    'default': "'foo'" if sys.version_info[0] >= 3 else "u'foo'",
                     'max_length': '16',
                     'workflow': self.frozen_workflow},  # **kwargs
             ), triple)
@@ -371,8 +383,8 @@ class SouthTestCase(test.TestCase):
 class TemplateTestCase(test.TestCase):
     """Tests states and transitions behavior in templates."""
 
-    uTrue = unicode(True)
-    uFalse = unicode(False)
+    uTrue = text_type(True)
+    uFalse = text_type(False)
 
     def setUp(self):
         self.obj = models.MyWorkflowEnabled()
@@ -415,10 +427,10 @@ class TemplateTestCase(test.TestCase):
 
     @unittest.skipIf(django_version[:2] < (1, 4), "foo.do_not_call_in_templates requires django>=1.4")
     def test_transaction_attributes(self):
-        self.assertEqual(self.render_fragment("{{ obj.foobar|safe}}"), unicode(self.obj.foobar))
+        self.assertEqual(self.render_fragment("{{ obj.foobar|safe}}"), text_type(self.obj.foobar))
         self.assertEqual(self.render_fragment("{{ obj.foobar.is_available }}"), self.uTrue)
         self.assertEqual(models.MyWorkflow.states.foo, self.obj.state)
 
-        self.assertEqual(self.render_fragment("{{ obj.bazbar|safe}}"), unicode(self.obj.bazbar))
+        self.assertEqual(self.render_fragment("{{ obj.bazbar|safe}}"), text_type(self.obj.bazbar))
         self.assertEqual(self.render_fragment("{{ obj.bazbar.is_available }}"), self.uFalse)
         self.assertEqual(models.MyWorkflow.states.foo, self.obj.state)
